@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2017 Montel Laurent <montel@kde.org>
+  Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -18,7 +18,7 @@
 #include "filterbalsamailtest.h"
 #include <MailImporter/FilterBalsa>
 #include "filterimportertest.h"
-#include <qtest.h>
+#include <QTest>
 
 FilterBalsaMailTest::FilterBalsaMailTest(QObject *parent)
     : QObject(parent)
@@ -36,34 +36,37 @@ void FilterBalsaMailTest::shouldImportData()
 void FilterBalsaMailTest::canNotImportDataEmptyPath()
 {
     MailImporter::FilterBalsa filter;
-    MailImporter::FilterInfo *info = new MailImporter::FilterInfo;
-    FilterImporterTest *importerTest = new FilterImporterTest(info);
+    MailImporter::FilterInfo info;
+    FilterImporterTest *importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
-    filter.setFilterInfo(info);
+    filter.setFilterInfo(&info);
     filter.importMails(QString());
     QVERIFY(importerTest->filterImporterDataList().isEmpty());
+    delete importerTest;
 }
 
 void FilterBalsaMailTest::canNotImportDataUnknowPath()
 {
     MailImporter::FilterBalsa filter;
-    MailImporter::FilterInfo *info = new MailImporter::FilterInfo;
-    FilterImporterTest *importerTest = new FilterImporterTest(info);
+    MailImporter::FilterInfo info;
+    FilterImporterTest *importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
-    filter.setFilterInfo(info);
+    filter.setFilterInfo(&info);
     filter.importMails(QStringLiteral("/foo/kde/bla/toto/"));
     QVERIFY(importerTest->filterImporterDataList().isEmpty());
+    delete importerTest;
 }
 
 void FilterBalsaMailTest::canNotImportDataWhenHomeDirSelected()
 {
     MailImporter::FilterBalsa filter;
-    MailImporter::FilterInfo *info = new MailImporter::FilterInfo;
-    FilterImporterTest *importerTest = new FilterImporterTest(info);
+    MailImporter::FilterInfo info;
+    FilterImporterTest *importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
-    filter.setFilterInfo(info);
+    filter.setFilterInfo(&info);
     filter.importMails(QDir::homePath());
     QVERIFY(importerTest->filterImporterDataList().isEmpty());
+    delete importerTest;
 }
 
 QTEST_MAIN(FilterBalsaMailTest)
